@@ -228,7 +228,7 @@ impl Web3 {
             .check_erc20_approved(token_in, eth_address, router)
             .await?;
         if !approved {
-            let nonce = self.eth_get_transaction_count(eth_address).await?;
+            let nonce = self.eth_get_transaction_count(eth_address).await? + 1u8.into();
             let _token_in_approval = self
                 .approve_erc20_transfers(
                     token_in,
